@@ -1,6 +1,6 @@
 package App::duino::Command::clean;
 {
-  $App::duino::Command::clean::VERSION = '0.07';
+  $App::duino::Command::clean::VERSION = '0.08';
 }
 
 use strict;
@@ -16,7 +16,7 @@ App::duino::Command::clean - Clean the build directory
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -29,18 +29,11 @@ sub abstract { 'clean the build directory' }
 sub usage_desc { '%c clean %o' }
 
 sub opt_spec {
-	my $arduino_board       = $ENV{'ARDUINO_BOARD'} || 'uno';
-
-	if (-e 'duino.ini') {
-		my $config = Config::INI::Reader -> read_file('duino.ini');
-
-		$arduino_board = $config -> {'_'} -> {'board'}
-			if $config -> {'_'} -> {'board'};
-	}
+	my ($self) = @_;
 
 	return (
 		[ 'board|b=s', 'specify the board model',
-			{ default => $arduino_board } ],
+			{ default => $self -> default_config('board') } ],
 	);
 }
 
